@@ -20,9 +20,11 @@
  *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *  Author: Dick Porter <dick@cymru.net>
+ *          Elliot Lee <sopwith@redhat.com>
  *
  */
 
+#include "config.h"
 #include <IIOP/IIOP.h>
 #include "orbit_types.h"
 #include "corba_object.h"
@@ -30,6 +32,9 @@
 #include "env.h"
 #include "orb.h"
 #include "interface_repository.h"
+#include <signal.h>
+#include <sys/types.h>
+#include <sys/wait.h>
 
 /* Section 4.2.1 */
 CORBA_InterfaceDef CORBA_Object_get_interface(CORBA_Object obj, CORBA_Environment *ev)
@@ -146,7 +151,7 @@ CORBA_boolean CORBA_Object_is_a(CORBA_Object obj, CORBA_char *logical_type_id, C
 
 		clsid = GPOINTER_TO_UINT(g_hash_table_lookup(ORBit_class_assignments, logical_type_id));
 
-		return (clsid && obj->vepv[clsid]);
+		return (clsid && (clsid < obj->vepv_size) && obj->vepv[clsid]);
 	} else if(!strcmp(obj->object_id, logical_type_id)
 		  || !strcmp("IDL:CORBA/Object:1.0", logical_type_id)) {
 		return CORBA_TRUE;
@@ -239,10 +244,47 @@ CORBA_boolean CORBA_Object_is_a(CORBA_Object obj, CORBA_char *logical_type_id, C
 }
 
 /* Section 4.2.5 */
+static void do_exit(int signum) {
+  _exit(5);
+}
+
+/* Lovely hack to try and figure out without hanging whether an object exists or not. */
 CORBA_boolean CORBA_Object_non_existent(CORBA_Object obj, CORBA_Environment *ev)
 {
-	g_assert(!"Not yet implemented");
-	return(CORBA_FALSE);
+  int childpid, exitstatus, itmp;
+
+  ev->_major = CORBA_NO_EXCEPTION;
+
+  if(obj == CORBA_OBJECT_NIL)
+	  return TRUE;
+
+  if(obj->servant)
+	  return FALSE;
+
+  if(obj->connection && obj->connection->is_valid)
+	  return FALSE;
+
+  childpid = fork();
+
+  if(!childpid) {
+	  GIOPConnection* cnx = NULL;
+	  struct sigaction sa;
+
+	  memset(&sa, 0, sizeof(sa));
+	  sa.sa_handler = do_exit;
+	  sigaction(SIGALRM, &sa, NULL);
+	  alarm(2);
+	  cnx = _ORBit_object_get_connection(obj);
+
+	  /* XXX todo - try invoking a strange operation on the object, and see what type of exception we get. */ 
+
+	  _exit((cnx == NULL)?1:0);
+  }
+
+  itmp = waitpid(childpid, &exitstatus, 0);
+
+  if(itmp < 0) return TRUE;
+  return WEXITSTATUS(exitstatus) && TRUE;
 }
 
 gboolean
