@@ -287,9 +287,12 @@ ORBit_demarshal_allocate_mem (CORBA_TypeCode tc, gint nelements)
 }
 
 static void
-dynany_init_default (gpointer *val, const CORBA_TypeCode tc, size_t size)
+dynany_init_default (gpointer *val, const CORBA_TypeCode tc)
 {
-	int i, sub_size;
+	int    i;
+	size_t size;
+
+	size = ORBit_gather_alloc_info (tc);
 
 	*val = ALIGN_ADDRESS (*val, ORBit_find_alignment (tc));
 
@@ -308,27 +311,33 @@ dynany_init_default (gpointer *val, const CORBA_TypeCode tc, size_t size)
 	case CORBA_tk_longlong:
 	case CORBA_tk_ulonglong:
 		memset (*val, 0, size);
+		*val = ((guchar *)*val) + size;
 		break;
 
 	case CORBA_tk_wstring:
 	case CORBA_tk_string:
 		*(CORBA_char **) *val = CORBA_string_dup ("");
+		*val = ((guchar *)*val) + size;
 		break;
 
 	case CORBA_tk_float:
 		*(CORBA_float *) *val = 0.0;
+		*val = ((guchar *)*val) + size;
 		break;
 
 	case CORBA_tk_double:
 		*(CORBA_double *) *val = 0.0;
+		*val = ((guchar *)*val) + size;
 		break;
 
 	case CORBA_tk_longdouble:
 		*(CORBA_long_double *) *val = 0.0;
+		*val = ((guchar *)*val) + size;
 		break;
 
 	case CORBA_tk_objref:
 		*(CORBA_Object *) *val = CORBA_OBJECT_NIL;
+		*val = ((guchar *)*val) + size;
 		break;
 
 	case CORBA_tk_any: {
@@ -339,12 +348,14 @@ dynany_init_default (gpointer *val, const CORBA_TypeCode tc, size_t size)
 		any->_value = NULL;
 
 		CORBA_any_set_release (any, CORBA_TRUE);
+		*val = ((guchar *)*val) + size;
 		break;
 	}
 
 	case CORBA_tk_TypeCode:
 		*(CORBA_Object *) *val = CORBA_Object_duplicate (
 			(CORBA_Object) TC_null, NULL);
+		*val = ((guchar *)*val) + size;
 		break;
 
  	case CORBA_tk_sequence: {
@@ -356,45 +367,35 @@ dynany_init_default (gpointer *val, const CORBA_TypeCode tc, size_t size)
 		s->_length = 0;
 		s->_buffer = NULL;
 		s->_release = CORBA_TRUE;
+
+		*val = ((guchar *)*val) + sizeof (CORBA_sequence_octet);
 		break;
 	}
 
 	case CORBA_tk_array:
-		sub_size = ORBit_gather_alloc_info (tc->subtypes [0]);
-
 		for (i = 0; i < tc->length; i++) 
-			dynany_init_default (
-				val, tc->subtypes [0], sub_size);
+			dynany_init_default (val, tc->subtypes [0]);
 		break;
 		
 	case CORBA_tk_except:
 	case CORBA_tk_struct:
-		for (i = 0; i < tc->sub_parts; i++) {
-			sub_size = ORBit_gather_alloc_info (
-				tc->subtypes [i]);
-			
-			dynany_init_default (
-				val, tc->subtypes [i], sub_size);
-		}
+		for (i = 0; i < tc->sub_parts; i++)
+			dynany_init_default (val, tc->subtypes [i]);
 		break;
 
 	case CORBA_tk_union: {
-		sub_size = ORBit_gather_alloc_info (
-			tc->discriminator);
-		dynany_init_default (
-			val, tc->discriminator, sub_size);
+		gpointer oldval = *val;
 
-		sub_size = ORBit_gather_alloc_info (
-			tc->subtypes [0]);
-		dynany_init_default (
-			val, tc->subtypes [0], sub_size);
+		dynany_init_default (val, tc->discriminator);
 
+		dynany_init_default (val, tc->subtypes [0]);
+
+		*val = ((guchar *)oldval) + size;
 		break;
 	}
 
 	case CORBA_tk_alias:
-		dynany_init_default (
-			val, tc->subtypes [0], size);
+		dynany_init_default (val, tc->subtypes [0]);
 		break;
 		
 	case CORBA_tk_fixed:
@@ -402,24 +403,16 @@ dynany_init_default (gpointer *val, const CORBA_TypeCode tc, size_t size)
 		g_warning ("Unhandled typecode");
 		break;
 	}
-
-	*val = *val + size;
 }
 
 static gpointer
 dynany_any_new_default (const CORBA_TypeCode tc)
 {
 	gpointer value;
-	int size;
+	gpointer p;
 
-	size = ORBit_gather_alloc_info (tc);
-
-	if (size) {
-		gpointer p;
-		p = value = ORBit_demarshal_allocate_mem (tc, 1);
-		dynany_init_default (&p, tc, size);
-	} else
-		value = NULL;
+	p = value = ORBit_demarshal_allocate_mem (tc, 1);
+	dynany_init_default (&p, tc);
 
 	return value;
 }
@@ -824,7 +817,7 @@ DynamicAny_DynAny_from_any (DynamicAny_DynAny obj,
 
 CORBA_any *
 DynamicAny_DynAny_to_any (DynamicAny_DynAny obj,
-		     CORBA_Environment *ev)
+			  CORBA_Environment *ev)
 {
 	DynAny    *dynany;
 	CORBA_any *any;
@@ -848,8 +841,8 @@ DynamicAny_DynAny_to_any (DynamicAny_DynAny obj,
 
 CORBA_boolean
 DynamicAny_DynAny_equal (DynamicAny_DynAny obj_a,
-		    DynamicAny_DynAny obj_b,
-		    CORBA_Environment *ev)
+			 DynamicAny_DynAny obj_b,
+			 CORBA_Environment *ev)
 {
 	DynAny *dynanya;
 	DynAny *dynanyb;
@@ -904,8 +897,8 @@ DynamicAny_DynAny_copy (DynamicAny_DynAny obj,
 
 void
 DynamicAny_DynAny_insert_string (DynamicAny_DynAny       obj,
-			    const CORBA_char  *value,
-			    CORBA_Environment *ev)
+				 const CORBA_char  *value,
+				 CORBA_Environment *ev)
 {
 	DynAny *dynany;
 
@@ -1363,7 +1356,7 @@ DynamicAny_DynEnum_set_as_ulong (DynamicAny_DynEnum obj,
 
 CORBA_FieldName
 DynamicAny_DynStruct_current_member_name (DynamicAny_DynStruct obj,
-				     CORBA_Environment *ev)
+					  CORBA_Environment *ev)
 {
 	DynAny *dynany;
 	CORBA_TypeCode tc;
