@@ -44,7 +44,8 @@ typedef enum {
 	ORBIT_PSEUDO_POLICY,
 	ORBIT_PSEUDO_TYPECODE,
 	ORBIT_PSEUDO_REQUEST,
-	ORBIT_PSEUDO_SERVERREQUEST
+	ORBIT_PSEUDO_SERVERREQUEST,
+	ORBIT_PSEUDO_CONTEXT
 } ORBit_PseudoObject_type;
 typedef struct ORBit_PseudoObject_struct *ORBit_PseudoObject;
 
@@ -92,7 +93,7 @@ typedef struct {
 void ORBit_set_object_key(ORBit_Object_info *info);
 
 CORBA_Object ORBit_create_object_with_info(GSList *profiles,
-					   CORBA_char *type_id,
+					   const CORBA_char *type_id,
 					   CORBA_ORB orb,
 					   CORBA_Environment *ev);
 
@@ -108,5 +109,6 @@ CORBA_Object ORBit_demarshal_object(GIOPRecvBuffer *recv_buffer,
 GSList *ORBit_demarshal_IOR(GIOPRecvBuffer *recv_buffer);
 
 extern void ORBit_delete_profiles(GSList *profile_list);
+GIOPConnection *ORBit_handle_location_forward(GIOPRecvBuffer *rb, CORBA_Object obj);
 
 #endif /* _ORBIT_ORBIT_OBJECT_H_ */
