@@ -5,6 +5,8 @@
 
 #include <unistd.h>
 
+#define BACKWARDS_COMPAT_0_4
+
 typedef struct {
   char *base_name, *c_base_name;
   FILE *fh;
@@ -16,7 +18,7 @@ typedef struct {
   guint8 last_tail_align;
   guint8 alloc_on_stack : 1; /* TRUE for demarshalling in skeletons, etc. */
   guint8 endian_swap_pass : 1; /* Demarshalling, again */
-  guint8 curptr_loaded : 1; /* ditto */
+  guint8 in_skels : 1;
 } OIDL_C_Marshal_Info;
 
 void orbit_idl_output_c(OIDL_Output_Tree *tree, OIDL_Run_Info *rinfo);
@@ -45,5 +47,7 @@ gboolean orbit_cbe_type_is_fixed_length(IDL_tree ts);
 void orbit_cbe_write_node_typespec(FILE *of, OIDL_Marshal_Node *node);
 gboolean orbit_cbe_type_is_builtin(IDL_tree);
 void orbit_cbe_param_printptrs(FILE *of, IDL_tree param, IDL_ParamRole role);
+void orbit_cbe_id_define_hack(FILE *fh, const char *def_prefix, const char *def_name, const char *def_value);
+void orbit_cbe_id_cond_hack(FILE *fh, const char *def_prefix, const char *def_name, const char *def_value);
 
 #endif
