@@ -10,7 +10,7 @@ Echo echo_client = CORBA_OBJECT_NIL;
 static CORBA_Object
 do_echoString(PortableServer_Servant servant,
 	      CORBA_char *astring,
-	      CORBA_long *outnum,
+	      CORBA_double *outnum,
 	      CORBA_Environment *ev);
 
 PortableServer_ServantBase__epv base_epv = {
@@ -67,10 +67,10 @@ main (int argc, char *argv[])
 static CORBA_Object
 do_echoString(PortableServer_Servant servant,
 	      CORBA_char *astring,
-	      CORBA_long *outnum,
+	      CORBA_double *outnum,
 	      CORBA_Environment *ev)
 {
-  *outnum = rand() % 100;
+  *outnum = (double)(rand() % 100)/100.0;
 
   /* g_message("[server] %s -> %d", astring, *outnum); */
 
